Learn R Programming

TLdating (version 0.1.3)

Risoe.BINfileData2TLum.BIN.File: Convert Risoe.BINfileData object to an TLum.BIN.File object.

Description

This function convert a Risoe.BINfileData object, created using the package'Luminescence', into a TLum.BIJ.file object, which will be used by this package. The TL package is implemented to only works with its own class of object (TLum.BIN.File, TLum.Analysis and TLum.Data.Curve).

Usage

Risoe.BINfileData2TLum.BIN.File(object, k)

Arguments

object
Risoe.BINfileData (required): object containing the TL curves used for the ED estimation.
k
numeric (required): Relative error of the TL signals. Generally, it is between 0.02 and 0.1.

Details

This function use the data from the Risoe.BINFileData and the k specified to create a absolute error matrix. Then it create a new TLum.BIN.File including all the information from the Risoe.BINFileData and the new absolute error matrix. For practical reason, the TLdating package considers the error as random. It means that the systematic component of the error will be ignored.

See Also

TLum.BIN.File2Risoe.BINfileData, TLum.BIN.File2TLum.Analysis and TLum.BIN.File2TLum.Data.Curve.