TLum.BIN.File2Risoe.BINfileData: Convert TLum.BIN.File object to an Risoe.BINfileData object.
Description
This function convert TLum.BIN.File object into a Risoe.BINfileData object that is usable by the Luminescence package.
Usage
TLum.BIN.File2Risoe.BINfileData(object)
Arguments
object
TLum.BIN.File (required): object containing the TL curves used for the ED estimation.
Value
This function return an Risoe.BINfileData containing all information previously stored in the TLum.BIN.File except the uncertainties matrix.
To avoid conflicts with other software, the original data type of each curves is restored.