Learn R Programming

TLdating (version 0.1.3)

analyse_TL.SAR: SAR protocol for thermoluminescence dating

Description

This function calculates the equivalent dose (ED) using the SAR protocol. See details for more information.

Usage

analyse_TL.SAR(object, eval.Tmin, eval.Tmax, rejection.criteria = list(recycling.ratio = 10, recuperation.rate = 10, testdose.error = 10, paleodose.error = 10), fitting.parameters = list(fit.method = "LIN", fit.weighted = FALSE, fit.rDoses.min = NA, fit.rDoses.max = NA), plotting.parameters = list(plot.Tmin = 0, plot.Tmax = NA, no.plot = FALSE))

Arguments

object
TLum.Analysis (required): object containing the TL curves used for the ED calculation.
eval.Tmin
integer (required): Temperature (°C) of the lowest boundary for the signal integration.
eval.Tmax
integer (required): Temperature (°C) of the upper boundary for the signal integration.
rejection.criteria
list (with default): list containing the rejection criteria (in %). See details.
fitting.parameters
list (with default): list containing the fitting parameters. See details.
plotting.parameters
list (with default): list containing the plotting parameters. See details.

Value

The results are plotted using plot_TL.SAR.The function also provides an TLum.Results containing:

Details

This function estimates the equivent dose in thermoluminescence dating using the SAR protocol. The equivalent dose is estimated for each disc using the growth curve approaches (QC) (Aitken, 1985) and the dose plateau approach (DP). Both approach should provide a similar result.

The Lx/Tx matrix is estimated using calc_TL.LxTx. The plateau test values are estimated using calc_TL.plateau.

Rejection criteria The rejection criteria are:

Fitting parameters The fitting parameters are:

See also calc_TL.SAR.fit.

Plotting parameters The plotting parameters are:

See also plot_TL.SAR.

References

Aitken, M.J. (1985) Thermoluminescence Dating, Academic Press, London

Murray & Wintle (2000). Luminescence dating of quartz using an improved single-aliquot regenerative-dose protocol. Radiation Measurements, Vol.32, No.1, p.57-73.

See Also

calc_TL.LxTx, calc_TL.plateau, calc_TL.SAR.fit, analyse_TL.MAAD.