Learn R Programming

TLdating (version 0.1.3)

calc_TL.MAAD.fit.I: Estimation of the supralinearity value for the MAAD protocol

Description

Internal function called by analyse_TL.MAAD. This function estimates the supralinearity correction based on the dose vector and the Lx/Tx vector provided. See details for more information.

Usage

calc_TL.MAAD.fit.I(LxTx, LxTx.error, doses, slope = NULL, fitting.parameters = list(fit.method = "LIN", fit.weighted = FALSE, fit.use.slope = FALSE))

Arguments

LxTx
numeric (required): Lx/Tx vector
LxTx.error
numeric (required): Error for the Lx/Tx vector
doses
numeric (required): doses vector
slope
list (with default): Property of the additive growth curve.
fitting.parameters
list (with default): fitting parameters. See details.

Value

The function provides an TLum.Results object containing:

Details

This function estimates the supralinearity correction based on the doses vector and the Lx/Tx matrix provided. Different fitting methods are available (LIN, EXP, EXP+LIN or EXP+EXP). Morover, the fitting can be weigthed or not. If the fitting parameter fit.use.slope is TRUE, the function will use the data from slope to define the fitting curve for the supralinearity correction. In that case, the supralinearity correction growth curve will be parallel to the additive growth curve.

#' Fitting parameters The fitting parameters are:

Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.

See Also

calc_TL.MAAD.fit.Q, analyse_TL.MAAD.