Learn R Programming

TLdating (version 0.1.3)

calc_TL.MAAD.fit.Q: Estimation of the palaeodose (Q) with the MAAD protocol

Description

Internal function called by analyse_TL.MAAD. This function makes a first estimation of the palaeodose based on a doses vector and a Lx/Tx vector provided. See details for more information.

Usage

calc_TL.MAAD.fit.Q(LxTx, LxTx.error, doses, fitting.parameters = list(fit.method = "LIN", fit.weighted = FALSE))

Arguments

LxTx
numeric (required): Lx/Tx vector
LxTx.error
numeric (required): Error for the Lx/Tx vector
doses
numeric (required): doses vector
fitting.parameters
list (with default): fitting parameters. See details.

Value

The function provides an TLum.Results object containing:

Details

This function estimates the equivalent dose before any supralineary correction based on the doses vector and the Lx/Tx matrix provided. Different fitting methods are available (LIN, EXP, EXP+LIN or EXP+EXP). Moreover, the fitting can be weigthed or not.

#' Fitting parameters The fitting parameters are:

Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.

See Also

calc_TL.MAAD.fit.I, analyse_TL.MAAD.