Learn R Programming

TLdating (version 0.1.3)

calc_TL.MAAD.separate: Separate the additive and the regenerative curves

Description

Internal function called by analyse_TL.MAAD. This function separates the additive curves from the regenerative curves using a vector containing the data type associate with each curve. Additive curves have "Natural" or "N+dose" as datatype. Regenerative curves have "Bleach" or "Bleach+dose" as datatype. Other datatypes are not supported.

Usage

calc_TL.MAAD.separate(Lx, Lx.error, doses, dTypes)

Arguments

Lx
numeric (required): Lx matrix
Lx.error
numeric (required): Error for the Lx matrix.
doses
numeric (required): doses vector
dTypes
character (required): data type vector.

Details

Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.