Learn R Programming

TLdating (version 0.1.3)

calc_TL.SAR.fit: Estimation of the equivalent dose (ED) value for the SAR protocol

Description

Internal function called by analyse_TL.SAR. This function estimates the equivalent dose (ED) based on a doses vector and a Lx/Tx vector provided. See details for more information.

Usage

calc_TL.SAR.fit(doses, LnTn, LnTn.error, LxTx, LxTx.error, fitting.parameters = list(fit.method = "LIN", fit.weighted = FALSE))

Arguments

doses
numeric (required): doses vector
LnTn
numeric (required): Ln/Tn.
LnTn.error
numeric (required): Error for the Ln/Tn.
LxTx
numeric (required): Lx/Tx vector
LxTx.error
numeric (required): Error for the Lx/Tx vector
fitting.parameters
list (with default): fitting parameters. See details.

Value

The function provides an TLum.Results object containing:

Details

This function estimates the equivalent dose based on the doses vector, Ln/Tn and the Lx/Tx matrix provided. Different fitting methods are available (LIN, EXP, EXP+LIN or EXP+EXP). Moreover, the fitting can be weigthed or not.

Fitting parameters The fitting parameters are:

Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.

See Also

analyse_TL.SAR.