Learn R Programming

TLdating (version 0.1.3)

calc_TL.plateau: Estimate value for plateau test

Description

The function estimates the quotient between the natural and the additive/regenerate signal.

Usage

calc_TL.plateau(Ln, Ln.error, Lx, Lx.error)

Arguments

Ln
numeric (required): Ln vector
Ln.error
numeric (required): Error for the Ln vector
Lx
numeric (required): Ln matrix
Lx.error
numeric (required): Error for the Lx matrix

Value

The function provides an TLum.Results object containing:

Details

Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.