Learn R Programming

TLdating (version 0.1.3)

calc_TL.temperature: calculate temperature vector

Description

This function calculates the temperature vector.

Usage

calc_TL.temperature(nPoints, Tmax, Hrate, an_temp = 0, an_time = 0, rec_ramp2PH = FALSE, rec_duringPH = FALSE)

Arguments

nPoints
numeric (required): number of points.
Tmax
numeric (required): Maximum temperature.
Hrate
numeric (required): Heating rate.
an_temp
numeric (with default): Annealing temperature.
an_time
numeric (with default): Annealing time.
rec_ramp2PH
logical (with default): Indicate if the signal was record during the ramp up to the preheat temperature.
rec_duringPH
logical (with default): Indicate if the signal was record during the preheat plateau.

Value

This function provides a new TLum.Results object containing the times and temperature vectors.

Details

Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.