use_DRAC4brick: Calculation of the dose rate for a brick sample coming from a cave
Description
This function allows to estimating the dose rate for a grain which was surrounded by brick and mortar.
It call the use_DRAC and calc_CosmicDoseRate functions from the R package 'Luminescence'.
The function 'use_DRAC' is only compatible wth DRAC version 1.1.
Usage
use_DRAC4brick(data, notification = TRUE)
Arguments
notification
logical (default): set to FALSE if you don't want to see the legal notification. Value
This function return a TLum.Results object containing the Age estimation, the dose rates
(total, internal, external, environmental, alpha, beta, gamma and cosmic), the equivalent dose used and their uncertainties.