use_DRAC4flint: Calculation of the dose rate for a flint
Description
This function allows to estimating the dose rate for a burnt flint object which was surrounded by sediment.
It call the use_DRAC and calc_CosmicDoseRate functions from the R package 'Luminescence'.
The function 'use_DRAC' is only compatible wth DRAC version 1.1.
Usage
use_DRAC4flint(data, notification = TRUE)
Arguments
notification
logical (default): set to FALSE if you don't want to see the legal notification. Value
This function return a TLum.Results object containing the Age estimation, the dose rates
(total, internal, external, environmental, alpha, beta, gamma and cosmic), the equivalent dose used and their uncertainties.