Internal function called by analyse_TL.MAAD and analyse_TL.SAR.
This function separates the Lx matrix from the Tx matrix.
Then, it estimates the Lx/Tx matrix.
It also provides a name for each of the curves.
Usage
calc_TL.LxTx(object)
Arguments
object
TLum.Analysis (required): TLum.Analysis object
Value
The function provides an TLum.Results containing:
Details
Warning: This function is an internal function and should not be used except for development purposes.
Internal functions can be heavily modified and even renamed or removed in new version of the package.
References
Aitken, M.J. (1985) Thermoluminescence Dating, Academic Press, London
Murray & Wintle (2000). Luminescence dating of quartz using an improved single-aliquot regenerative-dose protocol. Radiation Measurements, Vol.32, No.1, p.57-73.