calc_TL.MAAD.fit.I(LxTx, LxTx.error, doses, slope = NULL, fitting.parameters = list(fit.method = "LIN", fit.weighted = FALSE, fit.use.slope = FALSE))LIN, EXP, EXP+LIN or EXP+EXP).
Morover, the fitting can be weigthed or not.
If the fitting parameter fit.use.slope is TRUE, the function will use the data
from slope to define the fitting curve for the supralinearity correction.
In that case, the supralinearity correction growth curve will be parallel to the additive growth curve.#' Fitting parameters The fitting parameters are:
Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.