calc_TL.SAR.fit(doses, LnTn, LnTn.error, LxTx, LxTx.error, fitting.parameters = list(fit.method = "LIN", fit.weighted = FALSE))LIN, EXP, EXP+LIN or EXP+EXP).
Moreover, the fitting can be weigthed or not. Fitting parameters The fitting parameters are:
Warning: This function is an internal function and should not be used except for development purposes. Internal functions can be heavily modified and even renamed or removed in new version of the package.