logical (with default): Indicate if the signal was record during the ramp up to the preheat temperature.
rec_duringPH
logical (with default): Indicate if the signal was record during the preheat plateau.
Value
This function provides a new TLum.Results object containing the times and temperature vectors.
Details
Warning: This function is an internal function and should not be used except for development purposes.
Internal functions can be heavily modified and even renamed or removed in new version of the package.