Rdocumentation
powered by
Learn R Programming
TLdating (version 0.1.3)
mod_extract.aliquot: extract aliquots
Description
This function extracts a list of aliquots from a
TLum.Analysis
object.
Usage
mod_extract.aliquot(object, list)
Arguments
object
TLum.Analysis
(
required
): object containing the initial TL curves.
list
numeric
(
required
): list containing the position of the aliquots that shall be used.
Value
This function provides a
TLum.Data.Curve
object containing only the aliquots specified in the list.