Rdocumentation
powered by
Learn R Programming
TLdating (version 0.1.3)
mod_remove.aliquot: Remove aliquots
Description
This function removes a list of aliquots from a
TLum.Analysis
object.
Usage
mod_remove.aliquot(object, list)
Arguments
object
TLum.Analysis
(
required
): object containing the initial TL curves.
list
numeric
(
required
): list containing the position of the aliquots to remove.
Value
This function provides a
TLum.Analysis
without the aliquots specified in the list.